//
//  ViewController.m
//  OldTimeRadio
//
//  Created by Brian Moakley on 5/26/14.
//  Copyright (c) 2014 Razeware. All rights reserved.
//

#import "ViewController.h"
#import "OTREpisode.h"
#import "OTRSite.h"
#import "OTRShow.h"
#import "OTRFavorite.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    NSFileManager * fileManager = [NSFileManager defaultManager];
    NSURL * otrURL = [[fileManager URLForDirectory:NSLibraryDirectory inDomain:NSUserDomainMask appropriateForURL:nil create:NO error:nil] URLByAppendingPathComponent:@"otr.bin"];
    NSData * otrData = [NSData dataWithContentsOfURL:otrURL options:NSDataReadingMappedIfSafe error:nil];
    
    if (!otrData)
    {
        NSString * plistPath = [[NSBundle mainBundle] pathForResource:@"old_time_radio" ofType:@"plist"];
        NSURL * plistUrl = [NSURL fileURLWithPath:plistPath];
        NSData * plistData = [NSData dataWithContentsOfURL:plistUrl options:NSDataReadingMappedIfSafe error:nil];
        
        NSDictionary * oldTimeRadio = [NSPropertyListSerialization propertyListFromData:plistData mutabilityOption:NSPropertyListImmutable format:nil errorDescription:nil];
        
        NSMutableArray * sites = [@[] mutableCopy];
        NSMutableArray * shows = [@[] mutableCopy];
        NSMutableArray * episodes = [@[] mutableCopy];
        NSMutableArray * favorites = [@[] mutableCopy];
        
        for (NSDictionary * siteDictionary in oldTimeRadio[@"Sites"])
        {
            OTRSite * otrSite = [[OTRSite alloc] init];
            otrSite.name = siteDictionary[@"Name"];
            otrSite.address = siteDictionary[@"Address"];
            otrSite.isFree = [(NSNumber *)siteDictionary[@"Is Free"] boolValue];
            otrSite.isMembershipRequired = [(NSNumber *)siteDictionary[@"Membership Required"] boolValue];
            
            [sites addObject:otrSite];
        }
        
        for (NSDictionary * siteDictionary in oldTimeRadio[@"Shows"])
        {
            OTRShow * otrShow = [[OTRShow alloc] init];
            otrShow.showId = [(NSNumber *) siteDictionary[@"Id"] integerValue];
            otrShow.title = siteDictionary[@"Title"];
            otrShow.thumbnailFileName = siteDictionary[@"Thumbnail"];
            otrShow.showDescription = siteDictionary[@"Description"];
            
            [shows addObject:otrShow];
        }
        
        for (NSDictionary * siteDictionary in oldTimeRadio[@"Episodes"])
        {
            OTREpisode * episode = [[OTREpisode alloc] init];
            NSInteger showId = [(NSNumber *)siteDictionary[@"Show Id"] integerValue];
            for (OTRShow * show in shows)
            {
                if (show.showId == showId)
                {
                    episode.parentShow = show;
                    break;
                }
            }
            episode.broadcastDate = siteDictionary[@"Broadcast Date"];
            episode.fileLocation = siteDictionary[@"File Location"];
            episode.title = siteDictionary[@"Title"];
            episode.episodeId = [siteDictionary[@"Episode Id"] integerValue];
            [episodes addObject:episode];
        }
        
        for (NSDictionary * siteDictionary in oldTimeRadio[@"Favorites"])
        {
            OTRFavorite * favorite = [[OTRFavorite alloc] init];
            for (OTREpisode * episode in episodes)
            {
                if (episode.episodeId == [(NSNumber * ) siteDictionary[@"Episode Id"] integerValue])
                {
                    favorite.episode = episode;
                    episode.favorite = favorite;
                    break;
                }
            }
            favorite.note = siteDictionary[@"Note"];
            favorite.favoriteDate = siteDictionary[@"Favorite Date"];
            [favorites addObject:favorite];
        }
        
        
        NSDictionary * objectGraph = @{ @"Favorites" : favorites, @"Shows" : shows, @"Episodes" : episodes, @"Sites" : sites };
        otrData = [NSKeyedArchiver archivedDataWithRootObject:objectGraph];
        [otrData writeToURL:otrURL options:NSDataWritingAtomic error:nil];
    }
    
    NSDictionary * otrEpisode = [NSKeyedUnarchiver unarchiveObjectWithData:otrData];
    
    NSArray * episodes = otrEpisode[@"Episodes"];
    for (OTREpisode * episode in episodes)
    {
        NSLog(@"%@", episode);
    }
    
    NSArray * favorites = otrEpisode[@"Favorites"];
    for (OTRFavorite * favorite in favorites)
    {
        NSLog(@"%@", favorite);
    }
    
    NSArray * shows = otrEpisode[@"Shows"];
    for (OTRShow * show in shows)
    {
        NSLog(@"%@", show);
    }
    
    NSArray * sites = otrEpisode[@"Sites"];
    for (OTRSite * site in sites)
    {
        NSLog(@"%@", site);
    }
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    
}

@end
